pub struct ComponentAuctionRequest {
pub component_ref: String,
pub component_id: ComponentId,
pub constraints: HashMap<String, String>,
}Expand description
A request to locate suitable hosts for a given component
Fields
component_ref: StringThe image reference, file or OCI, for this component.
component_id: ComponentIdThe unique identifier to be used for this component. The host will ensure that no other component with the same ID is running on the host
constraints: HashMap<String, String>The set of constraints that must match the labels of a suitable target host