pub struct ComponentInstance {
pub annotations: Option<HashMap<String, String>>,
pub image_ref: String,
pub instance_id: String,
pub revision: i32,
pub max_instances: u32,
}Fields
annotations: Option<HashMap<String, String>>The annotations that were used in the start request that produced this component instance
image_ref: StringImage reference for this component
instance_id: StringThis instance’s unique ID (guid)
revision: i32The revision number for this component instance
max_instances: u32The maximum number of concurrent requests this instance can handle