pub struct ScaleComponentCommand {
pub component_ref: String,
pub component_id: ComponentId,
pub annotations: Option<HashMap<String, String>>,
pub max_instances: u32,
pub host_id: String,
pub config: Vec<String>,
}Fields
component_ref: StringImage reference for the component.
component_id: ComponentIdUnique identifier of the component to scale.
annotations: Option<HashMap<String, String>>Optional set of annotations used to describe the nature of this component scale command. For example, autonomous agents may wish to “tag” scale requests as part of a given deployment
max_instances: u32The maximum number of concurrent executing instances of this component. Setting this to 0 will
stop the component.
host_id: StringHost ID on which to scale this component
config: Vec<String>A list of named configs to use for this component. It is not required to specify a config. Configs are merged together before being given to the component, with values from the right-most config in the list taking precedence. For example, given ordered configs foo {a: 1, b: 2}, bar {b: 3, c: 4}, and baz {c: 5, d: 6}, the resulting config will be: {a: 1, b: 3, c: 5, d: 6}