pub struct StartProviderCommand {
pub annotations: Option<HashMap<String, String>>,
pub provider_id: ComponentId,
pub config: Vec<String>,
pub host_id: String,
pub provider_ref: String,
}Expand description
A command sent to a host requesting a capability provider be started with the given link name and optional configuration.
Fields
annotations: Option<HashMap<String, String>>Optional set of annotations used to describe the nature of this provider start command. For example, autonomous agents may wish to “tag” start requests as part of a given deployment
provider_id: ComponentIdUnique identifier of the provider to start.
config: Vec<String>A list of named configs to use for this provider. It is not required to specify a config. Configs are merged together before being given to the provider, with values from the right-most config in the list taking precedence. For example, given ordered configs foo {a: 1, b: 2}, bar {b: 3, c: 4}, and baz {c: 5, d: 6}, the resulting config will be: {a: 1, b: 3, c: 5, d: 6}
host_id: StringThe host ID on which to start the provider
provider_ref: StringThe image reference of the provider to be started